@@ -2,7 +2,7 @@
 #define oxygenbaseengine_h
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
 *
 * This  library is free  software; you can  redistribute it and/or
 * modify it  under  the terms  of the  GNU Lesser  General  Public
@@ -41,8 +41,7 @@ namespace Oxygen
             _enabled( true )
         {}
 
-        virtual ~BaseEngine()
-        {}
+        virtual ~BaseEngine(){}
 
         //! register widget
         virtual bool registerWidget( GtkWidget* widget );
