@@ -41,8 +41,8 @@ namespace Oxygen
         _list = 0L;
 
         // connect signals
-        _stateChangeId.connect( G_OBJECT(widget), "state-changed", G_CALLBACK( stateChangeEvent ), this );
-        _styleSetId.connect( G_OBJECT(widget), "style-set", G_CALLBACK( styleSetEvent ), this );
+        _stateChangeId.connect( G_OBJECT(widget), "state-flags-changed", G_CALLBACK( stateChangeEvent ), this );
+        _styleUpdatedId.connect( G_OBJECT(widget), "style-updated", G_CALLBACK( styleUpdatedEvent ), this );
 
         // initialize cell view
         initializeCellView( widget );
@@ -63,7 +63,7 @@ namespace Oxygen
         #endif
 
         _stateChangeId.disconnect();
-        _styleSetId.disconnect();
+        _styleUpdatedId.disconnect();
 
         // clear pointers to widgets
         _target = 0L;
@@ -360,11 +360,11 @@ namespace Oxygen
     }
 
     //________________________________________________________________________________
-    void ComboBoxData::stateChangeEvent( GtkWidget*, GtkStateType, gpointer data )
+    void ComboBoxData::stateChangeEvent( GtkWidget*, GtkStateFlags, gpointer data )
     { static_cast<ComboBoxData*>( data )->updateCellViewColor(); }
 
     //________________________________________________________________________________
-    void ComboBoxData::styleSetEvent( GtkWidget*, GtkStyle*, gpointer data )
+    void ComboBoxData::styleUpdatedEvent( GtkWidget*, gpointer data )
     { static_cast<ComboBoxData*>( data )->updateCellViewColor(); }
 
 }
