@@ -35,7 +35,7 @@ namespace Oxygen
     {
 
         #if OXYGEN_DEBUG
-        std::cerr << "Oxygen::HoverData::connect - " << widget << " (" << (widget ? G_OBJECT_TYPE_NAME( widget ):"null") << ")" << std::endl;
+        std::cerr << "Oxygen::HoverData::connect - " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")" << std::endl;
         #endif
 
         const bool enabled( gtk_widget_get_state( widget ) != GTK_STATE_INSENSITIVE );
@@ -45,8 +45,12 @@ namespace Oxygen
         if( enabled )
         {
 
-            gint xPointer,yPointer;
-            gdk_window_get_pointer( gtk_widget_get_window( widget ), &xPointer, &yPointer, 0L);
+            gint xPointer(0), yPointer(0);
+
+            GdkDeviceManager* manager( gdk_display_get_device_manager( gtk_widget_get_display( widget ) ) );
+            GdkDevice* pointer( gdk_device_manager_get_client_pointer( manager ) );
+
+            gdk_window_get_device_position( gtk_widget_get_window( widget ), pointer, &xPointer, &yPointer, 0L);
             const GtkAllocation allocation( Gtk::gtk_widget_get_allocation( widget ) );
             const GdkRectangle rect( Gtk::gdk_rectangle( 0, 0, allocation.width, allocation.height ) );
             setHovered( widget, Gtk::gdk_rectangle_contains( &rect, xPointer, yPointer ) );
@@ -66,7 +70,7 @@ namespace Oxygen
     void HoverData::disconnect( GtkWidget* widget )
     {
         #if OXYGEN_DEBUG
-        std::cerr << "Oxygen::HoverData::disconnect - " << widget << " (" << (widget ? G_OBJECT_TYPE_NAME( widget ):"null") << ")" << std::endl;
+        std::cerr << "Oxygen::HoverData::disconnect - " << widget << " (" << G_OBJECT_TYPE_NAME( widget ) << ")" << std::endl;
         #endif
 
         _enterId.disconnect();
