@@ -24,11 +24,13 @@
 * MA 02110-1301, USA.
 */
 
+#include "oxygenrgba.h"
+
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
-#include <string>
 
-#include "oxygenrgba.h"
+#include <cmath>
+#include <string>
 
 namespace Oxygen
 {
@@ -47,6 +49,9 @@ namespace Oxygen
         return out;
     }
 
+    //! streamer for GtkWidgetPath
+    std::ostream& operator << ( std::ostream& out, const GtkWidgetPath* path );
+
     //! GtkContainer streamer
     inline std::ostream& operator << (std::ostream& out, GtkContainer* container)
     {
@@ -75,6 +80,7 @@ namespace Oxygen
         //@{
 
         //! returns OxygenRgba color from GdkColor
+        /*! TODO: remove as obsolete */
         inline ColorUtils::Rgba gdk_get_color( const GdkColor& color )
         {
             return ColorUtils::Rgba(
@@ -83,7 +89,11 @@ namespace Oxygen
                 double(color.blue)/0xffff );
         }
 
-        //! map window origin to top level
+        //! returns OxygenRgba color from GdkColor
+        inline ColorUtils::Rgba gdk_get_color( const GdkRGBA& color )
+        { return ColorUtils::Rgba( color.red, color.green, color.blue, color.alpha ); }
+
+        //! map widget origin to top level
         /*!
         x and y correspond to (0,0) maped to toplevel window;
         w and h correspond to toplevel window frame size
@@ -167,10 +177,24 @@ namespace Oxygen
 
         //@}
 
+        //! get arrow orientation from angle
+        inline GtkArrowType gtk_arrow_get_type( const double& angle )
+        {
+            static const double delta( 0.001 );
+            if( std::abs( angle ) < delta ) return GTK_ARROW_UP;
+            else if( std::abs( angle - M_PI/2 ) < delta ) return GTK_ARROW_RIGHT;
+            else if( std::abs( angle - M_PI ) < delta ) return GTK_ARROW_DOWN;
+            else return GTK_ARROW_LEFT;
+        }
+
         //! returns true if widget's layout is reversed
         inline bool gtk_widget_layout_is_reversed( GtkWidget* widget )
         { return widget ? gtk_widget_get_direction( widget ) == GTK_TEXT_DIR_RTL : false; }
 
+        //! returns true if widget's layout is reversed
+        inline bool gtk_theming_engine_layout_is_reversed( GtkThemingEngine* engine )
+        { return engine ? gtk_theming_engine_get_direction( engine ) == GTK_TEXT_DIR_RTL : false; }
+
         //! set all buttons in the container to state NORMAL
         void gtk_container_adjust_buttons_state( GtkContainer*, gpointer=0L );
 
@@ -188,6 +212,9 @@ namespace Oxygen
 
         }
 
+        //! returns true if given path as given type
+        bool gtk_widget_path_has_type( const GtkWidgetPath*, GType );
+
         //! returns true if widget is a groupbox (a la Qt)
         inline bool gtk_widget_is_groupbox( GtkWidget* widget )
         {
@@ -269,10 +296,6 @@ namespace Oxygen
         inline GtkWidget* gtk_parent_tree_view( GtkWidget* widget )
         { return gtk_widget_find_parent( widget, GTK_TYPE_TREE_VIEW ); }
 
-        //! return parent combobox if any.
-        inline GtkWidget* gtk_parent_combo( GtkWidget* widget )
-        { return gtk_widget_find_parent( widget, GTK_TYPE_COMBO ); }
-
         //! return parent combobox if any.
         inline GtkWidget* gtk_parent_combobox( GtkWidget* widget )
         { return gtk_widget_find_parent( widget, GTK_TYPE_COMBO_BOX ); }
@@ -280,19 +303,8 @@ namespace Oxygen
         //! return parent combobox if any.
         inline GtkWidget* gtk_parent_combobox_entry( GtkWidget* widget )
         {
-            // try get parent combobox entry
-            GtkWidget* out(0L);
-            if( ( out = gtk_widget_find_parent( widget, GTK_TYPE_COMBO_BOX_ENTRY ) ) ) return out;
-
-            // if not found, get parent combobox and check if it has an entry
-            if( !(out = gtk_widget_find_parent( widget, GTK_TYPE_COMBO_BOX ) ) ) return 0L;
-
-            #if GTK_CHECK_VERSION(2, 24, 0)
-            return gtk_combo_box_get_has_entry( GTK_COMBO_BOX( out ) ) ? out:0L;
-            #else
-            return GTK_IS_ENTRY( gtk_bin_get_child( GTK_BIN( out ) ) ) ? out:0L;
-            #endif
-
+            GtkWidget* parent( gtk_parent_combobox( widget ) );
+            return ( parent && gtk_combo_box_get_has_entry( GTK_COMBO_BOX( parent ) ) ) ? parent:0L;
         }
 
         //! return parent scrolled window if any.
@@ -333,9 +345,6 @@ namespace Oxygen
         //! true if scrolled window must be forced to have a sunken frame
         bool gtk_scrolled_window_force_sunken( GtkWidget* );
 
-        //! returns true if widget is a tooltip, useful when GTK_IS_TOOLTIP() gives false for real tooltip
-        bool gtk_is_tooltip( GtkWidget* widget );
-
         //!@name button utilities
         //@{
 
@@ -368,20 +377,14 @@ namespace Oxygen
         //! true if widget is the treeview of a combobox
         bool gtk_combobox_is_tree_view( GtkWidget* );
 
-        //! true if widget is the scrolled window of a combobox
+        //! true if widget is the treeview of a combobox
         bool gtk_combobox_is_scrolled_window( GtkWidget* );
 
-        //! true if widget is the viewport of a combo
-        bool gtk_combo_is_viewport( GtkWidget* );
+        //! true if widget is the treeview of a combobox
+        bool gtk_combobox_is_viewport( GtkWidget* );
 
-        //! true if widget is the frame of a combo
-        bool gtk_combo_is_frame( GtkWidget* );
-
-        //! true if widget is the popup window of a combobox
-        bool gtk_combobox_is_popup( GtkWidget* );
-
-        //! true if widget is the popup window of a combo
-        bool gtk_combo_is_popup( GtkWidget* );
+        //! true if widget is the treeview of a combobox
+        bool gtk_combobox_is_frame( GtkWidget* );
 
         //! true if combobox must appear as list
         bool gtk_combobox_appears_as_list( GtkWidget* );
@@ -424,44 +427,6 @@ namespace Oxygen
 
         //! returns a widget which has response_id as response id for dialog
         GtkWidget* gtk_dialog_find_button( GtkDialog*, gint );
-
-        //! store quarks
-        class Quarks
-        {
-            public:
-
-            //! parent class
-            inline static GQuark rcStyle( void )
-            {
-
-                // try initialize
-                if( !_rcStyle )
-                { _rcStyle = g_quark_try_string( "gtk-rc-style" ); }
-
-                return _rcStyle;
-
-            }
-
-
-            private:
-
-            //! RC style quark
-            /*!
-            used to check whether an RCStyle was installed on a given widget or not.
-            See gtkwidet::gtk_widget_get_modifier_style()
-            */
-            static GQuark _rcStyle;
-
-        };
-
-        //! returns true if widget style color is modified
-        inline bool gtk_widget_style_is_modified( GtkWidget* widget, GtkStateType state, GtkRcFlags flag )
-        {
-            const bool hasRCStyle( g_object_get_qdata (G_OBJECT (widget), Quarks::rcStyle() ) );
-            return ( hasRCStyle && gtk_widget_get_modifier_style(widget)->color_flags[state]&flag );
-        }
-
-
     }
 
 }
