@@ -23,6 +23,7 @@
 #include "oxygencoloreffect.h"
 #include "oxygencolorutils.h"
 #include "oxygenfontinfo.h"
+#include "oxygentimeline.h"
 #include "config.h"
 
 #include <gtk/gtk.h>
@@ -193,11 +194,11 @@ namespace Oxygen
         if( gtk_widget_get_default_direction() == GTK_TEXT_DIR_RTL )
         {
 
-            _css.addToCurrentSection( "  -GtkButton-inner-border: 1 0 0 10;" );
+            _css.addToCurrentSection( "  -GtkButton-inner-border: 1px 0px 0px 10px;" );
 
         } else {
 
-            _css.addToCurrentSection( "  -GtkButton-inner-border: 1 10 0 0;" );
+            _css.addToCurrentSection( "  -GtkButton-inner-border: 1px 10px 0px 0px;" );
 
         }
 
@@ -667,7 +668,7 @@ namespace Oxygen
         // tooltips
         _css.addSection( "GtkWindow#gtk-tooltip" );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_BACKGROUND_COLOR, _palette.color( Palette::Tooltip ) ) );
-        _css.addToCurrentSection( Gtk::CSSOption<int>( "padding", 3 ) );
+        _css.addToCurrentSection( "  padding: 3px;" );
 
         _css.addSection( "GtkWindow#gtk-tooltip GtkLabel" );
         _css.addToCurrentSection( Gtk::CSSOption<std::string>( GTK_STYLE_PROPERTY_COLOR, _palette.color( Palette::TooltipText ) ) );
@@ -899,6 +900,9 @@ namespace Oxygen
         _menuFollowMouseAnimationsDuration = oxygen.getOption( "[Style]", "MenuFollowMouseAnimationsDuration" ).toVariant<int>(40);
         _toolBarAnimationsDuration = oxygen.getOption( "[Style]", "ToolBarAnimationsDuration" ).toVariant<int>(50);
 
+        // animation steps
+        TimeLine::setSteps( oxygen.getOption( "[Style]", "AnimationSteps" ).toVariant<int>( 10 ) );
+
         // window decoration button size
         std::string buttonSize( oxygen.getValue( "[Windeco]", "ButtonSize", "Normal") );
         if( buttonSize == "Small" ) _buttonSize = ButtonSmall;
