@@ -37,16 +37,12 @@
 #include "oxygenstyleoptions.h"
 #include "oxygentaboptions.h"
 #include "oxygentileset.h"
+#include "oxygenwidgetlookup.h"
 #include "oxygenwindecooptions.h"
 #include "oxygenwindecobutton.h"
 #include "oxygenwindowmanager.h"
-
 #include <gdk/gdk.h>
 
-#ifdef GDK_WINDOWING_X11
-#include <X11/Xdefs.h>
-#endif
-
 namespace Oxygen
 {
 
@@ -67,7 +63,7 @@ namespace Oxygen
         }
 
         //! initialize
-        bool initialize( unsigned int flags = QtSettings::All );
+        void initialize( unsigned int flags = QtSettings::All );
 
         //! settings
         const QtSettings& settings( void ) const
@@ -105,171 +101,188 @@ namespace Oxygen
         WindowManager& windowManager( void )
         { return _windowManager; }
 
+        //! widget lookup
+        WidgetLookup& widgetLookup( void )
+        { return _widgetLookup; }
+
         //! return tabCloseButton for given set of options
         Cairo::Surface tabCloseButton( const StyleOptions& );
 
         //! background surface
         bool hasBackgroundSurface( void ) const;
 
-        //! update kwin blur region
-        void setWindowBlur(GdkWindow* window,bool enable);
-
         //!@name primitives
         //@{
 
         //! fill given rectangle with flat color
-        void fill( GdkWindow* window, GdkRectangle* r, gint x, gint y, gint w, gint h, Palette::Role role ) const
-        { fill( window, r, x, y, w, h, settings().palette().color( Palette::Active, role ) ); }
+        void fill( cairo_t* context, gint x, gint y, gint w, gint h, Palette::Role role ) const
+        { fill( context, x, y, w, h, settings().palette().color( Palette::Active, role ) ); }
 
         //! fill given rectangle with flat color
-        void fill( GdkWindow* window, GdkRectangle* r, gint x, gint y, gint w, gint h, Palette::Group group, Palette::Role role ) const
-        { fill( window, r, x, y, w, h, settings().palette().color( group, role ) ); }
+        void fill( cairo_t* context, gint x, gint y, gint w, gint h, Palette::Group group, Palette::Role role ) const
+        { fill( context, x, y, w, h, settings().palette().color( group, role ) ); }
 
         //! fill given rectangle with flat color
-        void fill( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const ColorUtils::Rgba& color ) const;
+        void fill( cairo_t*, gint, gint, gint, gint, const ColorUtils::Rgba& color ) const;
 
         //! outline given rectangle with flat color
-        void outline( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const ColorUtils::Rgba& color = ColorUtils::Rgba( 1, 0, 0 ) ) const;
+        void outline( cairo_t*, gint, gint, gint, gint, const ColorUtils::Rgba& color = ColorUtils::Rgba( 1, 0, 0 ) ) const;
 
         //! separators
-        void drawSeparator( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions& );
+        void drawSeparator( GtkWidget*, cairo_t*, gint, gint, gint, gint, const StyleOptions& );
+        void drawSeparator( cairo_t* context, gint x, gint y, gint w, gint h, const StyleOptions& options )
+        { drawSeparator( 0L, context, x, y, w, h, options ); }
 
         //! window background
         /*! returns true if window gradient could be rendered */
-        bool renderWindowBackground( cairo_t*, GdkWindow*, GtkWidget*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions& = StyleOptions(), TileSet::Tiles = TileSet::Center, bool isMaximized=false );
-        bool renderWindowBackground( cairo_t* c, gint x, gint y, gint w, gint h, bool maximized, StyleOptions& options )
-        { return renderWindowBackground( c, 0, 0, 0, x, y, w, h, options, TileSet::Center, maximized );}
+        bool renderWindowBackground( cairo_t*, GdkWindow*, GtkWidget*, gint, gint, gint, gint, const StyleOptions& = StyleOptions(), TileSet::Tiles = TileSet::Center );
 
-        bool renderWindowBackground( GdkWindow* window, GtkWidget* widget, GdkRectangle* r, gint x, gint y, gint w, gint h, const StyleOptions& o = StyleOptions(), TileSet::Tiles tiles= TileSet::Center )
-        { return renderWindowBackground( 0L, window, widget, r, x, y, w, h, o, tiles ); }
-
-        bool renderWindowBackground( GdkWindow* window, GdkRectangle* r, gint x, gint y, gint w, gint h, const StyleOptions& o = StyleOptions(), TileSet::Tiles tiles = TileSet::Center)
-        { return renderWindowBackground( window, 0L, r, x, y, w, h, o, tiles ); }
+        bool renderWindowBackground( cairo_t* context, GdkWindow* window, gint x, gint y, gint w, gint h, const StyleOptions& o = StyleOptions(), TileSet::Tiles tiles= TileSet::Center)
+        { return renderWindowBackground( context, window, 0L, x, y, w, h, o, tiles ); }
 
         //! groupbox background
-        bool renderGroupBoxBackground( GdkWindow* window, GtkWidget* widget, GdkRectangle* r, gint x, gint y, gint w, gint h, const StyleOptions& o, TileSet::Tiles tiles = TileSet::Center )
-        { return renderGroupBoxBackground( 0L, window, widget, r, x, y, w, h, o, tiles ); }
+        bool renderGroupBoxBackground( cairo_t*, GtkWidget*, gint, gint, gint, gint, const StyleOptions&, TileSet::Tiles = TileSet::Center );
 
-        bool renderGroupBoxBackground( cairo_t*, GdkWindow*, GtkWidget*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions&, TileSet::Tiles = TileSet::Center );
-
-        //! menu background
-        bool renderMenuBackground( GdkWindow*, Cairo::Context&, gint, gint, gint, gint, const StyleOptions& ) const;
-        bool renderMenuBackground( GdkWindow* window, GdkRectangle* r, gint x, gint y, gint w, gint h, const StyleOptions& o) const
-        { Cairo::Context c(window,r); return renderMenuBackground(window, c, x, y, w, h, o); }
+        //! window background
+        bool renderMenuBackground( cairo_t*, gint, gint, gint, gint, const StyleOptions& ) const;
 
         //! tooltip background
-        void renderTooltipBackground( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions& ) const;
+        void renderTooltipBackground( cairo_t*, gint, gint, gint, gint, const StyleOptions& ) const;
 
         //! tree view header
-        void renderHeaderBackground( GdkWindow*, GdkRectangle*, gint, gint, gint, gint );
+        void renderHeaderBackground( cairo_t*, GdkWindow*, GtkWidget*, gint, gint, gint, gint );
+        void renderHeaderBackground( cairo_t* context, GdkWindow* window, gint x, gint y, gint w, gint h )
+        { renderHeaderBackground( context, window, 0L, x, y, w, y ); }
 
         //! tree view header
-        void renderHeaderLines( GdkWindow*, GdkRectangle*, gint, gint, gint, gint ) const;
+        void renderHeaderLines( cairo_t*, gint, gint, gint, gint ) const;
 
         //! tree view lines
-        void renderTreeLines( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const Gtk::CellInfoFlags&, const StyleOptions& ) const;
+        void renderTreeLines( cairo_t*, gint, gint, gint, gint, const Gtk::CellInfoFlags&, const StyleOptions& ) const;
 
-        //! editors hole
-        /*! returns true if window gradient could be rendered */
-        void renderHoleBackground( GdkWindow*, GtkWidget*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions&, TileSet::Tiles = TileSet::Ring, gint = Entry_SideMargin );
-        void renderHoleBackground( GdkWindow* window, GtkWidget* widget, GdkRectangle* clip, gint x, gint y, gint w, gint h, TileSet::Tiles tiles = TileSet::Ring, gint margin = Entry_SideMargin )
-        { renderHoleBackground( window, widget, clip, x, y, w, h, StyleOptions(), tiles, margin ); }
+        //!@name editors hole
+        //@{
+        void renderHoleBackground( cairo_t*, GdkWindow*, GtkWidget*, gint, gint, gint, gint, const StyleOptions&, TileSet::Tiles = TileSet::Ring, gint = Entry_SideMargin );
+
+        void renderHoleBackground( cairo_t* context, GdkWindow* window, GtkWidget* widget, gint x, gint y, gint w, gint h, TileSet::Tiles tiles = TileSet::Ring, gint margin = Entry_SideMargin )
+        { renderHoleBackground( context, window, widget, x, y, w, h, StyleOptions(), tiles, margin ); }
+
+        void renderHoleBackground( cairo_t* context, GdkWindow* window, gint x, gint y, gint w, gint h, TileSet::Tiles tiles = TileSet::Ring, gint margin = Entry_SideMargin )
+        { renderHoleBackground( context, window, 0L, x, y, w, h, StyleOptions(), tiles, margin ); }
+
+        //@}
 
         //! splitters
-        void renderSplitter( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions&, const AnimationData& = AnimationData() ) const;
+        void renderSplitter( cairo_t*, gint, gint, gint, gint, const StyleOptions&, const AnimationData& = AnimationData() ) const;
 
         //!@name progressbar
         //@{
-        void renderProgressBarHole( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions& );
-        void renderProgressBarHandle( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions& );
+        void renderProgressBarHole( cairo_t*, gint, gint, gint, gint, const StyleOptions& );
+        void renderProgressBarHandle( cairo_t*, gint, gint, gint, gint, const StyleOptions& );
         //@}
 
         //!@name scrollbar
         //@{
-        void renderScrollBarHole( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions& );
-        void renderScrollBarHandle( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions&, const AnimationData& = AnimationData() );
+        void renderScrollBarHole( cairo_t*, gint, gint, gint, gint, const StyleOptions& );
+        void renderScrollBarHandle( cairo_t*, gint, gint, gint, gint, const StyleOptions&, const AnimationData& = AnimationData() );
         //@}
 
         //! toolbar handle
-        void renderToolBarHandle( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions& ) const;
+        void renderToolBarHandle( cairo_t*, gint, gint, gint, gint, const StyleOptions& ) const;
 
         //! frame
-        void drawFloatFrame( cairo_t* context, GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions&, Palette::Role = Palette::Window ) const;
-        void drawFloatFrame( GdkWindow* window, GdkRectangle* r, gint x, gint y, gint w, gint h, const StyleOptions& opt, Palette::Role role = Palette::Window) const
-        { drawFloatFrame( 0L, window, r, x, y, w, h, opt, role ); }
+        void drawFloatFrame( cairo_t*, gint, gint, gint, gint, const StyleOptions&, Palette::Role = Palette::Window ) const;
 
-        //! button slab
-        void renderButtonSlab( GdkWindow* window, GdkRectangle* clipRect, gint x, gint y, gint w, gint h, const StyleOptions& options, TileSet::Tiles tiles = TileSet::Ring )
-        { renderButtonSlab( window, clipRect, x, y, w, h, options, AnimationData(), tiles ); }
+        //!@name button slab
+        //@{
+        void renderButtonSlab( GtkWidget*, cairo_t*, gint, gint, gint, gint, const StyleOptions&, const AnimationData&, TileSet::Tiles = TileSet::Ring );
 
-        void renderButtonSlab( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions&, const AnimationData&, TileSet::Tiles = TileSet::Ring );
+        void renderButtonSlab( cairo_t* context, gint x, gint y, gint w, gint h, const StyleOptions& options, const AnimationData& data, TileSet::Tiles tiles = TileSet::Ring )
+        { renderButtonSlab( 0L, context, x, y, w, h, options, data, tiles ); }
+
+        void renderButtonSlab( GtkWidget* widget, cairo_t* context, gint x, gint y, gint w, gint h, const StyleOptions& options, TileSet::Tiles tiles = TileSet::Ring )
+        { renderButtonSlab( widget, context, x, y, w, h, options, AnimationData(), tiles ); }
+
+        void renderButtonSlab( cairo_t* context, gint x, gint y, gint w, gint h, const StyleOptions& options, TileSet::Tiles tiles = TileSet::Ring )
+        { renderButtonSlab( 0L, context, x, y, w, h, options, AnimationData(), tiles ); }
+        //@}
 
         //! checkbox
         /*! shadow type is used to decide whether check is on/off or tristate */
-        void renderCheckBox( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, GtkShadowType, const StyleOptions&, const AnimationData& = AnimationData() );
+        void renderCheckBox( GtkWidget*, cairo_t*, gint, gint, gint, gint, GtkShadowType, const StyleOptions&, const AnimationData& = AnimationData() );
+        void renderCheckBox( cairo_t* context, gint x, gint y, gint w, gint h, GtkShadowType shadow, const StyleOptions& options, const AnimationData& data = AnimationData() )
+        { renderCheckBox( 0L, context, x, y, w, h, shadow, options, data ); }
 
         //! radio button
-        void renderRadioButton( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, GtkShadowType, const StyleOptions&, const AnimationData& = AnimationData() );
+        void renderRadioButton( GtkWidget*, cairo_t*, gint, gint, gint, gint, GtkShadowType, const StyleOptions&, const AnimationData& = AnimationData() );
+        void renderRadioButton( cairo_t* context, gint x, gint y, gint w, gint h, GtkShadowType shadow, const StyleOptions& options, const AnimationData& data = AnimationData() )
+        { renderRadioButton( 0L, context, x, y, w, h, shadow, options, data ); }
 
         //!@name generic slab
         //@{
 
-        void renderSlab( GdkWindow* window, GdkRectangle* clipRect, int x, gint y, gint w, gint h, const StyleOptions& options, const AnimationData& animationData = AnimationData() )
-        { renderSlab( window, clipRect, x, y, w, h, Gtk::Gap(), options, animationData ); }
-
-        void renderSlab( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const Gtk::Gap&, const StyleOptions&, const AnimationData& = AnimationData() );
+        void renderSlab( cairo_t*, gint, gint, gint, gint, const Gtk::Gap&, const StyleOptions&, const AnimationData& = AnimationData() );
+        void renderSlab( cairo_t* context, int x, gint y, gint w, gint h, const StyleOptions& options, const AnimationData& animationData = AnimationData() )
+        { renderSlab( context, x, y, w, h, Gtk::Gap(), options, animationData ); }
 
         //@}
 
         //! info bar
-        void renderInfoBar( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const ColorUtils::Rgba& );
+        void renderInfoBar( GtkWidget*, cairo_t*, gint, gint, gint, gint, const ColorUtils::Rgba& );
+        void renderInfoBar( cairo_t* context, gint x, gint y, gint w, gint h, const ColorUtils::Rgba& color )
+        { renderInfoBar( 0L, context, x, y, w, h, color ); }
 
         //!@name hole
         //@{
 
-        void renderHole( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const Gtk::Gap&, const StyleOptions&, const AnimationData& = AnimationData(), TileSet::Tiles = TileSet::Ring );
+        void renderHole( cairo_t*, gint, gint, gint, gint, const Gtk::Gap&, const StyleOptions&, const AnimationData& = AnimationData(), TileSet::Tiles = TileSet::Ring );
 
-        void renderHole( GdkWindow* window, GdkRectangle* r, gint x, gint y, gint w, gint h, const StyleOptions& o, TileSet::Tiles tiles = TileSet::Ring )
-        { renderHole( window, r, x, y, w, h, Gtk::Gap(), o, AnimationData(), tiles ); }
+        void renderHole( cairo_t* context, gint x, gint y, gint w, gint h, const StyleOptions& o, TileSet::Tiles tiles = TileSet::Ring )
+        { renderHole( context, x, y, w, h, Gtk::Gap(), o, AnimationData(), tiles ); }
 
-        void renderHole( GdkWindow* window, GdkRectangle* r, gint x, gint y, gint w, gint h, const StyleOptions& o, const AnimationData& animationData, TileSet::Tiles tiles = TileSet::Ring )
-        { renderHole( window, r, x, y, w, h, Gtk::Gap(), o, animationData, tiles ); }
+        void renderHole( cairo_t* context, gint x, gint y, gint w, gint h, const StyleOptions& o, const AnimationData& animationData, TileSet::Tiles tiles = TileSet::Ring )
+        { renderHole( context, x, y, w, h, Gtk::Gap(), o, animationData, tiles ); }
 
         //@}
 
         //!@name dock frame
         //@{
-        void renderDockFrame( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const Gtk::Gap&, const StyleOptions& );
-        void renderDockFrame( GdkWindow* window, GdkRectangle* r, gint x, gint y, gint w, gint h, const StyleOptions& o )
-        { renderDockFrame( window, r, x, y, w, h, Gtk::Gap(), o ); }
+
+        void renderDockFrame( GtkWidget*, cairo_t*, gint, gint, gint, gint, const Gtk::Gap&, const StyleOptions& );
+        void renderDockFrame( cairo_t* context, gint x, gint y, gint w, gint h, const Gtk::Gap& gap, const StyleOptions& options )
+        { renderDockFrame( 0L, context, x, y, w, h, gap, options ); }
+
+        void renderDockFrame( cairo_t* context, gint x, gint y, gint w, gint h, const StyleOptions& options )
+        { renderDockFrame( 0L, context, x, y, w, h, Gtk::Gap(), options ); }
+
         //@}
 
         //! groupbox frame
-        void renderGroupBoxFrame( GdkWindow* window, GtkWidget*, GdkRectangle* r, gint x, gint y, gint w, gint h, const StyleOptions&  );
+        void renderGroupBoxFrame( cairo_t*, GtkWidget*, gint, gint, gint, gint, const StyleOptions&  );
 
         //! menu item
-        void renderMenuItemRect( GdkWindow*, GdkRectangle*, GtkWidget*, gint, gint, gint, gint, const StyleOptions&, const AnimationData& = AnimationData() );
+        void renderMenuItemRect( cairo_t*, GdkWindow*, GtkWidget*, gint, gint, gint, gint, const StyleOptions&, const AnimationData& = AnimationData() );
 
         //! selection
-        void renderSelection( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, TileSet::Tiles tiles, const StyleOptions& );
+        void renderSelection( cairo_t*, gint, gint, gint, gint, TileSet::Tiles tiles, const StyleOptions& );
 
         //! arrow
-        void renderArrow( GdkWindow*, GdkRectangle*, GtkArrowType, gint, gint, gint, gint, QtSettings::ArrowSize, const StyleOptions&, const AnimationData&, Palette::Role ) const;
-        void renderArrow( GdkWindow* window, GdkRectangle* clipRect, GtkArrowType type, gint x, gint y, gint w, gint h, QtSettings::ArrowSize size = QtSettings::ArrowNormal, const StyleOptions& options = Contrast, Palette::Role role = Palette::ButtonText ) const
-        { renderArrow( window, clipRect, type, x, y, w, h, size, options, AnimationData(), role ); }
+        void renderArrow( cairo_t*, GtkArrowType, gint, gint, gint, gint, QtSettings::ArrowSize, const StyleOptions&, const AnimationData&, Palette::Role ) const;
+        void renderArrow( cairo_t* context, GtkArrowType type, gint x, gint y, gint w, gint h, QtSettings::ArrowSize size = QtSettings::ArrowNormal, const StyleOptions& options = Contrast, Palette::Role role = Palette::ButtonText ) const
+        { renderArrow( context, type, x, y, w, h, size, options, AnimationData(), role ); }
 
         //! slider groove
-        void renderSliderGroove( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions& );
+        void renderSliderGroove( cairo_t*, gint, gint, gint, gint, const StyleOptions& );
 
         //! slider handle
-        void renderSliderHandle( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const StyleOptions&, const AnimationData& = AnimationData() );
+        void renderSliderHandle( cairo_t*, gint, gint, gint, gint, const StyleOptions&, const AnimationData& = AnimationData() );
 
         //! size grip
-        void renderSizeGrip( GdkWindow*, GdkRectangle*, GdkWindowEdge, gint, gint, gint, gint ) const;
+        void renderSizeGrip( cairo_t*, GdkWindowEdge, gint, gint, gint, gint ) const;
 
         //! tab
         void renderTab(
-            GdkWindow*, GdkRectangle*,
+            cairo_t*,
             gint, gint, gint, gint,
             GtkPositionType,
             const StyleOptions&,
@@ -278,19 +291,19 @@ namespace Oxygen
 
         //! tabbar base
         void renderTabBarBase(
-            GdkWindow*, GdkRectangle*,
+            cairo_t*,
             gint, gint, gint, gint,
             GtkPositionType, Gtk::Gap,
             const StyleOptions&,
             const TabOptions& );
 
         //! tabwidget frame
-        void renderTabBarFrame( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, const Gtk::Gap&, const StyleOptions& );
+        void renderTabBarFrame( cairo_t*, gint, gint, gint, gint, const Gtk::Gap&, const StyleOptions& );
 
         //! tree 'standard' expanders (that is: +!-)
-        void renderTreeExpander( GdkWindow*, GdkRectangle*, gint, gint, gint, gint, GtkExpanderStyle, const StyleOptions&, const AnimationData&, Palette::Role ) const;
-        void renderTreeExpander( GdkWindow* window, GdkRectangle* clipRect, gint x, gint y, gint w, gint h, GtkExpanderStyle style, const StyleOptions& options, Palette::Role role ) const
-        { renderTreeExpander( window, clipRect, x, y, w, h, style, options, AnimationData(), role ); }
+        void renderTreeExpander( cairo_t*, gint, gint, gint, gint, GtkExpanderStyle, const StyleOptions&, const AnimationData&, Palette::Role ) const;
+        void renderTreeExpander( cairo_t* context, gint x, gint y, gint w, gint h, GtkExpanderStyle style, const StyleOptions& options, Palette::Role role ) const
+        { renderTreeExpander( context, x, y, w, h, style, options, AnimationData(), role ); }
 
         //@}
 
@@ -307,17 +320,11 @@ namespace Oxygen
         void drawWindecoButton(cairo_t*,WinDeco::ButtonType,WinDeco::ButtonStatus,WinDeco::Options, gint,gint,gint,gint);
 
         // adjust scrollbar hole, depending on orientation and buttons settings
-        void adjustScrollBarHole( int& x, int& y, int& w, int& h, const StyleOptions& ) const;
+        void adjustScrollBarHole( gdouble& x, gdouble& y, gdouble& w, gdouble& h, const StyleOptions& ) const;
 
         //! sanitize size
         void sanitizeSize( GdkWindow* window, gint& width, gint& height ) const;
 
-        //! draw tab close x icon
-        void renderTabCloseIcon(cairo_t* context, GdkRectangle* r) const;
-
-        //! draw tab close button
-        void renderTabCloseButton(cairo_t* context, GdkRectangle* r, const ColorUtils::Rgba& base, const ColorUtils::Rgba& color);
-
         // get tiles for given tab orientation
         TileSet::Tiles tabTiles( GtkPositionType position ) const
         {
@@ -338,7 +345,8 @@ namespace Oxygen
         protected:
 
         //! constructor
-        Style( void );
+        explicit Style( void )
+        {}
 
         //! get color matching role from either style option or default palette
         const ColorUtils::Rgba& color( Palette::Role role, const StyleOptions& option ) const
@@ -359,7 +367,7 @@ namespace Oxygen
 
         //! tab
         void renderActiveTab(
-            GdkWindow*, GdkRectangle*,
+            cairo_t*,
             gint, gint, gint, gint,
             GtkPositionType,
             const StyleOptions&,
@@ -367,7 +375,7 @@ namespace Oxygen
 
         //! tab
         void renderInactiveTab_Plain(
-            GdkWindow*, GdkRectangle*,
+            cairo_t*,
             gint, gint, gint, gint,
             GtkPositionType,
             const StyleOptions&,
@@ -376,7 +384,7 @@ namespace Oxygen
 
         //! tab
         void renderInactiveTab_Single(
-            GdkWindow*, GdkRectangle*,
+            cairo_t*,
             gint, gint, gint, gint,
             GtkPositionType,
             const StyleOptions&,
@@ -393,11 +401,11 @@ namespace Oxygen
         void renderGroupBox( cairo_t*, const ColorUtils::Rgba&, gint, gint, gint, gint, const StyleOptions& = StyleOptions() );
 
         //! slab
-        void renderSlab( Cairo::Context&, gint, gint, gint, gint, const ColorUtils::Rgba&, const StyleOptions&, const AnimationData& = AnimationData(), TileSet::Tiles tiles = TileSet::Ring );
+        void renderSlab( cairo_t*, gint, gint, gint, gint, const ColorUtils::Rgba&, const StyleOptions&, const AnimationData& = AnimationData(), TileSet::Tiles tiles = TileSet::Ring );
 
         //! progressbar hole (groove)
         /*! also used for progress bars */
-        void renderScrollBarHole( Cairo::Context&, gint, gint, gint, gint, const ColorUtils::Rgba&, bool vertical, TileSet::Tiles = TileSet::Full );
+        void renderScrollBarHole( cairo_t*, gint, gint, gint, gint, const ColorUtils::Rgba&, bool vertical, TileSet::Tiles tiles = TileSet::Full );
 
         //! add hole mask to context
         void renderHoleMask( cairo_t*, gint, gint, gint, gint, TileSet::Tiles, gint );
@@ -425,13 +433,10 @@ namespace Oxygen
         void centerRect( GdkRectangle*, GdkRectangle* ) const;
 
         // generate map from gap
-        void generateGapMask( Cairo::Context&, gint, gint, gint, gint, const Gtk::Gap& ) const;
+        void generateGapMask( cairo_t*, gint, gint, gint, gint, const Gtk::Gap& ) const;
 
         //@}
 
-        //! monitored files is changed
-        static void fileChanged( GFileMonitor*, GFile*, GFile*, GFileMonitorEvent, gpointer );
-
         //! used to store slab characteristics
         class SlabRect
         {
@@ -490,6 +495,9 @@ namespace Oxygen
         //! window manager
         WindowManager _windowManager;
 
+        //! widget lookup
+        WidgetLookup _widgetLookup;
+
         //! background surface
         Cairo::Surface _backgroundSurface;
 
@@ -519,11 +527,6 @@ namespace Oxygen
         //! Tab close buttons
         TabCloseButtons _tabCloseButtons;
 
-        #ifdef GDK_WINDOWING_X11
-        //! Atom to show kwin what regions of translucent windows should be blurred
-        Atom _blurAtom;
-        #endif
-
         //! singleton
         static Style* _instance;
 
